# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.hourly_weather_response import HourlyWeatherResponse
from ...types.timezone import Timezone
from ...types.units import Units
from .personalized.client import AsyncPersonalizedClient, PersonalizedClient
from .raw_client import AsyncRawExperimentalClient, RawExperimentalClient
from .regional.client import AsyncRegionalClient, RegionalClient


class ExperimentalClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawExperimentalClient(client_wrapper=client_wrapper)
        self.regional = RegionalClient(client_wrapper=client_wrapper)

        self.personalized = PersonalizedClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawExperimentalClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExperimentalClient
        """
        return self._raw_client

    def extended(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HourlyWeatherResponse:
        """
        Get hourly weather forecast for a specific location and time

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HourlyWeatherResponse
            Successful Response

        Examples
        --------
        from silurian import Earth
        client = Earth(api_key="YOUR_API_KEY", )
        client.weather.experimental.extended(latitude=47.6061, longitude=-122.3328, )
        """
        _response = self._raw_client.extended(
            latitude=latitude, longitude=longitude, timezone=timezone, units=units, request_options=request_options
        )
        return _response.data


class AsyncExperimentalClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawExperimentalClient(client_wrapper=client_wrapper)
        self.regional = AsyncRegionalClient(client_wrapper=client_wrapper)

        self.personalized = AsyncPersonalizedClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawExperimentalClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExperimentalClient
        """
        return self._raw_client

    async def extended(
        self,
        *,
        latitude: float,
        longitude: float,
        timezone: typing.Optional[Timezone] = None,
        units: typing.Optional[Units] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HourlyWeatherResponse:
        """
        Get hourly weather forecast for a specific location and time

        Parameters
        ----------
        latitude : float

        longitude : float

        timezone : typing.Optional[Timezone]

        units : typing.Optional[Units]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HourlyWeatherResponse
            Successful Response

        Examples
        --------
        from silurian import AsyncEarth
        import asyncio
        client = AsyncEarth(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.weather.experimental.extended(latitude=47.6061, longitude=-122.3328, )
        asyncio.run(main())
        """
        _response = await self._raw_client.extended(
            latitude=latitude, longitude=longitude, timezone=timezone, units=units, request_options=request_options
        )
        return _response.data
